v1alpha1

package
v0.0.0-...-2441a6e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package v1alpha1 contains API Schema definitions for the k8s v1alpha1 API group +kubebuilder:object:generate=true +groupName=self.service.ovn.org

Index

Constants

This section is empty.

Variables

var (
	// GroupVersion is group version used to register these objects
	GroupVersion = schema.GroupVersion{Group: "self.service.ovn.org", Version: "v1alpha1"}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type OverlayNetwork

type OverlayNetwork struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec OverlayNetworkSpec `json:"spec,omitempty"`
}

OverlayNetwork is the Schema for the overlaynetworks API

func (*OverlayNetwork) DeepCopy

func (in *OverlayNetwork) DeepCopy() *OverlayNetwork

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OverlayNetwork.

func (*OverlayNetwork) DeepCopyInto

func (in *OverlayNetwork) DeepCopyInto(out *OverlayNetwork)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*OverlayNetwork) DeepCopyObject

func (in *OverlayNetwork) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type OverlayNetworkList

type OverlayNetworkList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []OverlayNetwork `json:"items"`
}

OverlayNetworkList contains a list of OverlayNetwork

func (*OverlayNetworkList) DeepCopy

func (in *OverlayNetworkList) DeepCopy() *OverlayNetworkList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OverlayNetworkList.

func (*OverlayNetworkList) DeepCopyInto

func (in *OverlayNetworkList) DeepCopyInto(out *OverlayNetworkList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*OverlayNetworkList) DeepCopyObject

func (in *OverlayNetworkList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type OverlayNetworkSpec

type OverlayNetworkSpec struct {
	// Name is the overlay network identifier.
	// The actual overlay network is prefixed with the current namespace
	// to assure uniqueness across namespaces.
	Name string `json:"name"`

	// The maximum transmission unit (MTU).
	// The default value, 1300, is automatically set by the kernel.
	// +optional
	Mtu string `json:"mtu,omitempty"`

	// The subnet to use for the network across the cluster.
	// Only include the CIDR for the node. E.g. 10.100.200.0/24.
	//
	// IPv6 (2001:DBB::/64) and dual-stack (192.168.100.0/24,2001:DBB::/64) subnets are supported.
	//
	// When omitted, the logical switch implementing the network only provides layer 2 communication,
	// and users must configure IP addresses for the pods.
	// Port security only prevents MAC spoofing.
	// +optional
	Subnets string `json:"subnets,omitempty"`

	// A comma-separated list of CIDRs and IP addresses.
	// IP addresses are removed from the assignable IP address pool and are never passed to the pods.
	// +optional
	ExcludeSubnets string `json:"excludeSubnets,omitempty"`
}

OverlayNetworkSpec defines the desired state of OverlayNetwork

func (*OverlayNetworkSpec) DeepCopy

func (in *OverlayNetworkSpec) DeepCopy() *OverlayNetworkSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OverlayNetworkSpec.

func (*OverlayNetworkSpec) DeepCopyInto

func (in *OverlayNetworkSpec) DeepCopyInto(out *OverlayNetworkSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to